// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "mailimporterakonadi_debug.h"


Q_LOGGING_CATEGORY(MAILIMPORTERAKONADI_LOG, "org.kde.pim.mailimporterakonadi", QtInfoMsg)

